@@ -19,4 +19,10 @@ eos.getTableRows({
     json: true,
 }).then(response => {
   console.log(JSON.stringify(response));
-});
\ No newline at end of file
+}).then(function (value){
+        console.log(value);
+        return value;
+      }).catch(function (e) {
+      console.error(e);
+      process.exit(1);
+      })
\ No newline at end of file
